@@ -44,6 +44,8 @@ class Node(resource.Resource):
     cluster_id = resource.Body('cluster_id')
     #: The ID of the profile used by this node.
     profile_id = resource.Body('profile_id')
+    #: The ID of the user who created this node.
+    user_id = resource.Body('user')
     #: The ID of the project this node belongs to.
     project_id = resource.Body('project')
     #: The name of the profile used by this node.
@@ -109,6 +111,20 @@ class Node(resource.Resource):
         }
         return self._action(session, body)
 
+    def op(self, session, operation, **params):
+        """Perform an operation on the specified node.
+
+        :param session: A session object used for sending request.
+        :param operation: A string representing the operation to be performed.
+        :param dict params: An optional dict providing the parameters for the
+                            operation.
+        :returns: A dictionary containing the action ID.
+        """
+        url = utils.urljoin(self.base_path, self.id, 'ops')
+        resp = session.post(url, endpoint_filter=self.service,
+                            json={operation: params})
+        return resp.json()
+
 
 class NodeDetail(Node):
     base_path = '/nodes/%(node_id)s?show_details=True'
