@@ -31,6 +31,15 @@ class Server(resource2.Resource, metadata.MetadataMixin):
 
     _query_mapping = resource2.QueryParameters("image", "flavor", "name",
                                                "status", "host", "all_tenants",
+                                               "sort_key", "sort_dir",
+                                               "reservation_id", "tags",
+                                               "project_id",
+                                               tags_any="tags-any",
+                                               not_tags="not-tags",
+                                               not_tags_any="not-tags-any",
+                                               is_deleted="deleted",
+                                               ipv4_address="ip",
+                                               ipv6_address="ip6",
                                                changes_since="changes-since")
 
     #: A list of dictionaries holding links relevant to this server.
@@ -111,17 +120,55 @@ class Server(resource2.Resource, metadata.MetadataMixin):
     personality = resource2.Body('personality')
     #: Configuration information or scripts to use upon launch.
     #: Must be Base64 encoded.
-    user_data = resource2.Body('user_data')
+    user_data = resource2.Body('OS-EXT-SRV-ATTR:user_data')
     #: Enables fine grained control of the block device mapping for an
     #: instance. This is typically used for booting servers from volumes.
-    block_device_mapping = resource2.Body('block_device_mapping_v2', type=dict)
+    block_device_mapping = resource2.Body('block_device_mapping_v2')
     #: The dictionary of data to send to the scheduler.
-    scheduler_hints = resource2.Body('os:scheduler_hints', type=dict)
+    scheduler_hints = resource2.Body('OS-SCH-HNT:scheduler_hints', type=dict)
     #: A networks object. Required parameter when there are multiple
     #: networks defined for the tenant. When you do not specify the
     #: networks parameter, the server attaches to the only network
     #: created for the current tenant.
     networks = resource2.Body('networks')
+    #: The hypervisor host name. Appears in the response for administrative
+    #: users only.
+    hypervisor_hostname = resource2.Body('OS-EXT-SRV-ATTR:hypervisor_hostname')
+    #: The instance name. The Compute API generates the instance name from the
+    #: instance name template. Appears in the response for administrative users
+    #: only.
+    instance_name = resource2.Body('OS-EXT-SRV-ATTR:instance_name')
+
+    def _prepare_request(self, requires_id=True, prepend_key=True):
+        request = super(Server, self)._prepare_request(requires_id=requires_id,
+                                                       prepend_key=prepend_key)
+
+        server_body = request.body[self.resource_key]
+
+        # Some names exist without prefix on requests but with a prefix
+        # on responses. If we find that we've populated one of these
+        # attributes with something and then go to make a request, swap out
+        # the name to the bare version.
+
+        # Availability Zones exist with a prefix on response, but not request
+        az_key = "OS-EXT-AZ:availability_zone"
+        if az_key in server_body:
+            server_body["availability_zone"] = server_body.pop(az_key)
+
+        # User Data exists with a prefix on response, but not request
+        ud_key = "OS-EXT-SRV-ATTR:user_data"
+        if ud_key in server_body:
+            server_body["user_data"] = server_body.pop(ud_key)
+
+        # Scheduler hints are sent in a top-level scope, not within the
+        # resource_key scope like everything else. If we try to send
+        # scheduler_hints, pop them out of the resource_key scope and into
+        # their own top-level scope.
+        hint_key = "OS-SCH-HNT:scheduler_hints"
+        if hint_key in server_body:
+            request.body[hint_key] = server_body.pop(hint_key)
+
+        return request
 
     def _action(self, session, body):
         """Preform server actions given the message body."""
@@ -205,6 +252,90 @@ class Server(resource2.Resource, metadata.MetadataMixin):
         body = {"removeSecurityGroup": {"name": security_group}}
         self._action(session, body)
 
+    def reset_state(self, session, state):
+        body = {"os-resetState": {"state": state}}
+        self._action(session, body)
+
+    def add_fixed_ip(self, session, network_id):
+        body = {"addFixedIp": {"networkId": network_id}}
+        self._action(session, body)
+
+    def remove_fixed_ip(self, session, address):
+        body = {"removeFixedIp": {"address": address}}
+        self._action(session, body)
+
+    def add_floating_ip(self, session, address, fixed_address=None):
+        body = {"addFloatingIp": {"address": address}}
+        if fixed_address is not None:
+            body['addFloatingIp']['fixed_address'] = fixed_address
+        self._action(session, body)
+
+    def remove_floating_ip(self, session, address):
+        body = {"removeFloatingIp": {"address": address}}
+        self._action(session, body)
+
+    def pause(self, session):
+        body = {"pause": None}
+        self._action(session, body)
+
+    def unpause(self, session):
+        body = {"unpause": None}
+        self._action(session, body)
+
+    def suspend(self, session):
+        body = {"suspend": None}
+        self._action(session, body)
+
+    def resume(self, session):
+        body = {"resume": None}
+        self._action(session, body)
+
+    def lock(self, session):
+        body = {"lock": None}
+        self._action(session, body)
+
+    def unlock(self, session):
+        body = {"unlock": None}
+        self._action(session, body)
+
+    def rescue(self, session, admin_pass=None, image_ref=None):
+        body = {"rescue": {}}
+        if admin_pass is not None:
+            body["rescue"]["adminPass"] = admin_pass
+        if image_ref is not None:
+            body["rescue"]["rescue_image_ref"] = image_ref
+        self._action(session, body)
+
+    def unrescue(self, session):
+        body = {"unrescue": None}
+        self._action(session, body)
+
+    def evacuate(self, session, host=None, admin_pass=None, force=None):
+        body = {"evacuate": {}}
+        if host is not None:
+            body["evacuate"]["host"] = host
+        if admin_pass is not None:
+            body["evacuate"]["adminPass"] = admin_pass
+        if force is not None:
+            body["evacuate"]["force"] = force
+        self._action(session, body)
+
+    def start(self, session):
+        body = {"os-start": None}
+        self._action(session, body)
+
+    def stop(self, session):
+        body = {"os-stop": None}
+        self._action(session, body)
+
+    def shelve(self, session):
+        body = {"shelve": None}
+        self._action(session, body)
+
+    def unshelve(self, session):
+        body = {"unshelve": None}
+        self._action(session, body)
+
 
 class ServerDetail(Server):
     base_path = '/servers/detail'
