@@ -20,28 +20,33 @@ class TestProfile(base.TestCase):
         prof = profile.Profile()
         expected = [
             'alarming',
+            'baremetal',
             'clustering',
             'compute',
             'database',
             'identity',
             'image',
             'key-manager',
+            'load_balancer',
             'messaging',
             'metering',
             'network',
             'object-store',
             'orchestration',
             'volume',
+            'workflowv2',
         ]
         self.assertEqual(expected, prof.service_keys)
 
     def test_default_versions(self):
         prof = profile.Profile()
+        self.assertEqual('v1', prof.get_filter('baremetal').version)
         self.assertEqual('v1', prof.get_filter('clustering').version)
         self.assertEqual('v2', prof.get_filter('compute').version)
         self.assertEqual('v1', prof.get_filter('database').version)
         self.assertEqual('v3', prof.get_filter('identity').version)
         self.assertEqual('v2', prof.get_filter('image').version)
+        self.assertEqual('v2', prof.get_filter('load_balancer').version)
         self.assertEqual('v2', prof.get_filter('network').version)
         self.assertEqual('v1', prof.get_filter('object-store').version)
         self.assertEqual('v1', prof.get_filter('orchestration').version)
@@ -54,6 +59,8 @@ class TestProfile(base.TestCase):
         prof = profile.Profile()
         prof.set_version('alarming', 'v2')
         self.assertEqual('v2', prof.get_filter('alarming').version)
+        prof.set_version('baremetal', 'v1')
+        self.assertEqual('v1', prof.get_filter('baremetal').version)
         prof.set_version('clustering', 'v1')
         self.assertEqual('v1', prof.get_filter('clustering').version)
         prof.set_version('compute', 'v2')
